==> medialibrary_0.6.0.orig.tar.bz2: medialibrary-0.6.0/src/filesystem/common/CommonFile.h <==
/*****************************************************************************
 * Media Library
 *****************************************************************************
 * Copyright (C) 2015-2019 Hugo Beauzée-Luyssen, Videolabs, VideoLAN
 *
 * Authors: Hugo Beauzée-Luyssen <hugo@beauzee.fr>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

#pragma once

#include "medialibrary/filesystem/IFile.h"

namespace medialibrary
{

namespace fs
{

class CommonFile : public IFile
{
public:
    CommonFile( const std::string& filePath );
    virtual const std::string& name() const override;
    virtual const std::string& extension() const override;
    virtual const std::string& mrl() const override;
    virtual bool isNetwork() const override;

protected:
    const std::string m_name;
    const std::string m_extension;
    const std::string m_mrl;
};

}

}

==> medialibrary_0.12.3.orig.tar.bz2: medialibrary-0.12.3/src/filesystem/common/CommonFile.h <==
/*****************************************************************************
 * Media Library
 *****************************************************************************
 * Copyright (C) 2015-2019 Hugo Beauzée-Luyssen, Videolabs, VideoLAN
 *
 * Authors: Hugo Beauzée-Luyssen <hugo@beauzee.fr>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

#pragma once

#include "medialibrary/filesystem/IFile.h"

namespace medialibrary
{

namespace fs
{

class CommonFile : public IFile
{
public:
    explicit CommonFile( std::string mrl );
    explicit CommonFile( std::string mrl, LinkedFileType linkedType,
                         std::string linkedFile );
    virtual const std::string& name() const override;
    virtual const std::string& extension() const override;
    virtual const std::string& mrl() const override;
    virtual bool isNetwork() const override;
    virtual LinkedFileType linkedType() const override;
    virtual const std::string& linkedWith() const override;

protected:
    const std::string m_mrl;
    const std::string m_name;
    const std::string m_extension;
    const std::string m_linkedFile;
    const LinkedFileType m_linkedType;
};

}

}
